==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property softDeleteTTL
 * @property subscriptionStateOverrideActions
 */
public data class
ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
    public val softDeleteTTL: Output<String>? = null,
    public val subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder()
            .softDeleteTTL(softDeleteTTL?.applyValue({ args0 -> args0 }))
            .subscriptionStateOverrideActions(
                subscriptionStateOverrideActions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs].
 */
@PulumiTagMarker
public class
ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgsBuilder
internal constructor() {
    private var softDeleteTTL: Output<String>? = null

    private var subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("slxxmctgeotwrfxu")
    public suspend fun softDeleteTTL(`value`: Output<String>) {
        this.softDeleteTTL = value
    }

    /**
     * @param value
     */
    @JvmName("fdrmccoasxmiapal")
    public suspend
    fun subscriptionStateOverrideActions(`value`: Output<List<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = value
    }

    @JvmName("vbhnnnodjwypqegq")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: Output<SubscriptionStateOverrideActionArgs>,
    ) {
        this.subscriptionStateOverrideActions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("auqetwyqhsukcrfq")
    public suspend
    fun subscriptionStateOverrideActions(values: List<Output<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("wyrwpmhyyfrdvhik")
    public suspend fun softDeleteTTL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteTTL = mapped
    }

    /**
     * @param value
     */
    @JvmName("gwtevrssawqmkbwd")
    public suspend
    fun subscriptionStateOverrideActions(`value`: List<SubscriptionStateOverrideActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vnucmkbeyubtljwp")
    public suspend
    fun subscriptionStateOverrideActions(argument: List<suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("piuknahugixceuue")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nrebbeuxesvmuvro")
    public suspend
    fun subscriptionStateOverrideActions(argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubscriptionStateOverrideActionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param values
     */
    @JvmName("ttchqldnqufdgkfl")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: SubscriptionStateOverrideActionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    internal fun build():
        ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
            softDeleteTTL = softDeleteTTL,
            subscriptionStateOverrideActions = subscriptionStateOverrideActions,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property softDeleteTTL
 * @property subscriptionStateOverrideActions
 */
public data class
ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
    public val softDeleteTTL: Output<String>? = null,
    public val subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder()
            .softDeleteTTL(softDeleteTTL?.applyValue({ args0 -> args0 }))
            .subscriptionStateOverrideActions(
                subscriptionStateOverrideActions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs].
 */
@PulumiTagMarker
public class
ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgsBuilder
internal constructor() {
    private var softDeleteTTL: Output<String>? = null

    private var subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("ffjbnkxdxnoewrbt")
    public suspend fun softDeleteTTL(`value`: Output<String>) {
        this.softDeleteTTL = value
    }

    /**
     * @param value
     */
    @JvmName("exixrxneghfrhele")
    public suspend
    fun subscriptionStateOverrideActions(`value`: Output<List<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = value
    }

    @JvmName("audxgueeaqgckmbd")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: Output<SubscriptionStateOverrideActionArgs>,
    ) {
        this.subscriptionStateOverrideActions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("trrsvtagsngbrfdp")
    public suspend
    fun subscriptionStateOverrideActions(values: List<Output<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ndglltxsswlmjxlj")
    public suspend fun softDeleteTTL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteTTL = mapped
    }

    /**
     * @param value
     */
    @JvmName("iosdivbbbralekot")
    public suspend
    fun subscriptionStateOverrideActions(`value`: List<SubscriptionStateOverrideActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vqgmqoutbqrshgel")
    public suspend
    fun subscriptionStateOverrideActions(argument: List<suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("stdbpalepvfnsypn")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("sltqqqaiuowllchi")
    public suspend
    fun subscriptionStateOverrideActions(argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubscriptionStateOverrideActionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param values
     */
    @JvmName("kgmcqpbvbklwpyii")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: SubscriptionStateOverrideActionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    internal fun build():
        ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        ResourceTypeRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
            softDeleteTTL = softDeleteTTL,
            subscriptionStateOverrideActions = subscriptionStateOverrideActions,
        )
}
